/*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
// (C) PicoPeta Simputers Pvt. Ltd. (2003)
// Author: Vivek K S, Rajat V, Girish A J 

#include <stdio.h>
#include <locale.h>
#include <libintl.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <fcntl.h>
#include <string.h>
#include "pgettext.h"
#include <utf2glyph.h>
#include <utfcapi.h>

static char pgettext_initialized=0;
static gettext_info info;

static void parse_line(char *line)
{
	const char* equal;
	unsigned int keylen = strlen(line);
	
	equal = strchr(line, '=');
	line[keylen-1] = '\0';
	if (equal != NULL)
	{
		if (strncmp(line, "font", 4) == 0)
		{
			strcpy(info.font, equal+1);
		}
		
		else if (strncmp(line, "bold", 4) == 0)
		{
			strcpy(info.bold, equal+1);
		}	
		else if (strncmp(line, "medium", 6) == 0)
		{
			strcpy(info.medium, equal+1);
		}

		else if (strncmp(line, "italics", 7) == 0)
		{
			strcpy(info.italics, equal+1);
		}

		else if (strncmp(line, "large", 5) == 0)
		{
			info.large = atoi(equal+1);
		}
		else if (strncmp(line, "normal", 6) == 0)
		{
			info.normal = atoi(equal+1);
		}
		else if (strncmp(line, "small", 5) == 0)
		{
			info.small = atoi(equal+1);
		}
		else if (strncmp(line, "tiny", 4) == 0)
		{
			info.tiny = atoi(equal+1);
		}
	}
}

void pgettext_init(const char *language, const char *domain)
{
	FILE *fp;
	int i=0;
	char line[BUF_LEN];
	struct stat sbuf;
	char local_lang[BUF_LEN];
	
	if (pgettext_initialized && strcmp(language, info.language) == 0)
		return;
	strcpy(local_lang, language);
	
	sprintf(line, "%s/%s/LC_MESSAGES/%s.mo",LOCALE_DIR, local_lang, domain);
	if(stat(line, &sbuf)) { // If MO file is not available default to english
		strcpy(local_lang, "en_US");
	}
	
	sprintf(line, LANG_SETTINGS_FILE, local_lang);
	if(stat(line, &sbuf)) {
		sprintf(line, LANG_SETTINGS_FILE, "en_US");
		if(stat(line, &sbuf)) {
			pgettext_initialized=0;
			return;
		}
	}
	fp=fopen(line, "r");

	while(fgets(line, BUF_LEN, fp)) 
		parse_line(line);
	fclose(fp);

	setlocale(LC_ALL,language); // language must be hg_IN, kg_IN or tg_IN
	bindtextdomain(domain, LOCALE_DIR );
	textdomain(domain);

	strcpy(info.language, local_lang);
	pgettext_initialized=1;
}

void pgettext_font(const char *style,const char* size, char* fontstring)
{
	fontstring[0] = '\0';
	
	if(pgettext_initialized)
	{
		unsigned int isize;
		char* local_style;

		if (strcmp(size, "large") == 0)
			isize = info.large;
		else if (strcmp(size, "small") == 0)
			isize = info.small;
		else if (strcmp(size, "tiny") == 0)
			isize = info.tiny;
		else
			isize = info.normal;

		if (strcmp(style, "bold") == 0)
			local_style = info.bold;
		else if (strcmp(style, "italics") == 0)
			local_style == info.italics;
		else
			local_style = info.medium;
		
		sprintf(fontstring, info.font, local_style, isize);
	}
}

char *pgettext(const char *msgid)
{
	const char* msg = gettext(msgid);
	char* retval;
	language l;
	int count=0;
	if (strcmp(info.language, "kg_IN") == 0)
		l =KANNADA;
	else if (strcmp(info.language, "tg_IN") == 0)
		l = TELUGU;
	else if (strcmp(info.language, "hg_IN") == 0)
		l = HINDI;
	else
	{
		retval = strdup(msg);
		return retval;
	}
	retval = utf_convert_to(msg, l);
	
	return retval;
}
